@@ -1,55 +1,24 @@
 package Net::Twitter::Error;
 use Moose;
-use Try::Tiny;
-use Devel::StackTrace;
 
-use overload '""' => \&error,
-             'fallback' => 1;
+use overload '""' => \&error;
 
-has twitter_error   => ( is => 'rw', predicate => 'has_twitter_error' );
+has twitter_error   => ( isa => 'HashRef', is => 'rw', predicate => 'has_twitter_error' );
 has http_response   => ( isa => 'HTTP::Response', is => 'rw', required => 1, handles => [qw/code message/] );
-has stack_trace     => ( is => 'ro', init_arg => undef, builder => '_build_stack_trace' );
-
-sub _build_stack_trace {
-    my $seen;
-    my $this_sub = (caller 0)[3];
-    Devel::StackTrace->new(frame_filter => sub {
-        my $caller = shift->{caller};
-        my $in_nt = $caller->[0] =~ /^Net::Twitter::/ || $caller->[3] eq $this_sub;
-        ($seen ||= $in_nt) && !$in_nt || 0;
-    });
-}
 
 sub error {
     my $self = shift;
 
-    # Twitter does not return a consintent error structure, so we have to
-    # try each known (or guessed) variant to find a suitable message...
-    my $error = $self->has_twitter_error && do {
-        my $e = $self->twitter_error;
-
-        # the newest: array of errors
-        try { exists $e->{errors} && exists $e->{errors}[0] && exists $e->{errors}[0]{message}
-            && $e->{errors}[0]{message} }
-
-        # it's single error variant
-        || try { exists $e->{error} && exists $e->{error}{message} && $e->{error}{message} }
-
-        # or maybe it's not that deep (documentation would be helpful, here, Twitter!)
-        || try { exists $e->{message} && $e->{message} }
-
-        # the original error structure
-        || try { exists $e->{error} && $e->{error} }
-    } || $self->http_response->status_line;
-
-    my ($location) = $self->stack_trace->frame(0)->as_string =~ /( at .*)/;
-    return $error . ($location || '');
+    # We MUST stringyfy to something that evaluates to true, or testing $@ will fail!
+    $self->has_twitter_error && $self->twitter_error->{error}
+        || ( $self->message . ": " . $self->code )
+        || '[unknown]';
 }
 
-__PACKAGE__->meta->make_immutable;
-
 no Moose;
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -123,6 +92,11 @@ Returns true if the object contains a Twitter error HASH.
 Returns the C<error> value from the C<twitter_error> HASH ref if there is one.
 Otherwise, it returns the string "[unknown]".
 
+=item stringify
+
+Returns the error element of the Twitter error HASH, if one exists.  Otherwise,
+it returns the HTTP message.  =back
+
 =back
 
 =head1 SEE ALSO
